TelemetryGuard

Struct TelemetryGuard 

pub struct TelemetryGuard { /* private fields */ }
Guard that manages telemetry lifecycle

When dropped, ensures proper cleanup of telemetry resources including flushing any pending trace/metric data to exporters.

Critical: Drop Behavior

The TelemetryGuard MUST outlive all traced code in your application.

When the guard is dropped, its Drop implementation:

  1. Flushes all pending traces to configured exporters (OTLP, etc.)
  2. Shuts down the OpenTelemetry tracer provider
  3. Releases telemetry resources

Common Pitfall

// ❌ WRONG: Guard dropped too early
{
    let _guard = TelemetryConfig::default().init()?;
} // Guard dropped here
my_traced_function().await; // Traces lost!
// ✅ CORRECT: Guard outlives traced code
let _guard = TelemetryConfig::default().init()?;
my_traced_function().await;
// Guard dropped at end of scope, traces flushed

Best Practice

Store the guard in your main application struct or as a variable in main():

#[tokio::main]
async fn main() -> Result<()> {
    let _telemetry = TelemetryConfig::default().init()?;

    // Run your server
    run_server().await?;

    Ok(())
    // Guard dropped here after server shutdown
}

Example

use turbomcp_telemetry::{TelemetryConfig, TelemetryGuard};

let config = TelemetryConfig::builder()
    .service_name("my-server")
    .build();

// Initialize telemetry - guard must be kept alive
let _guard = config.init()?;

// Your application code here...

// Telemetry is properly cleaned up when guard is dropped

Implementations

Source

impl TelemetryGuard

pub fn init(config: TelemetryConfig) -> Result<Self, TelemetryError>

Initialize telemetry with the provided configuration

pub fn service_name(&self) -> &str

Get the service name

pub fn service_version(&self) -> &str

Get the service version

pub fn config(&self) -> &TelemetryConfig

Get the configuration